unquad.estimation.conformal.ConformalDetector
=============================================

.. currentmodule:: unquad.estimation.conformal

.. autoclass:: ConformalDetector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ConformalDetector.__init__
      ~ConformalDetector.fit
      ~ConformalDetector.predict
   
   

   
   
   